@@ -185,7 +185,7 @@ def vol_target_indice_rebalancing(weight_data=None, vol_target = None, volatilit
     target_vol_values_list = []
     for date_index, row in weight_data.iterrows():
         if date_index == vol_target_inception_date:
-            volatility_factor = vol_target / weight_data.loc[vol_target_inception_date,'rolling_vol_indice']
+            volatility_factor = min(vol_target / weight_data.loc[vol_target_inception_date,'rolling_vol_indice'],1.)
             previous_value = initial_value
             target_vol_values_list.append({'Date': vol_target_inception_date, 'indice': initial_value, 'volatility_factor':np.nan})
             continue
@@ -195,7 +195,7 @@ def vol_target_indice_rebalancing(weight_data=None, vol_target = None, volatilit
         target_vol_values_list.append(current_values)
         # we readjust the volatility factor
         if row['is_rebalancing']:
-            volatility_factor = vol_target / weight_data.loc[date_index,'rolling_vol_indice']
+            volatility_factor = min(vol_target / weight_data.loc[date_index,'rolling_vol_indice'],1)
         previous_value = value
 
     target_vol_values_df = pd.DataFrame(target_vol_values_list)
@@ -209,6 +209,8 @@ def vol_target_indice_rebalancing(weight_data=None, vol_target = None, volatilit
             weight_data[me_consti] = weight_data[me_consti]*target_vol_values_df['volatility_factor']
 
     weight_data['cash'] = weight_data['cash']+(1-target_vol_values_df['volatility_factor'])*accumulated_lost_weight
+    # weights should sum to 1
+    #weight_data[['BRR Index', 'GC1 Comdty', 'HG1 Comdty', 'PA1 Comdty', 'SI1 Comdty', 'cash']].sum(axis = 1)
     weight_data = weight_data.drop(columns=['indice_returns', 'rolling_vol_indice'])
     return target_vol_values_df, weight_data
 
