@@ -132,6 +132,46 @@ def plot_box_plot_sig_vs_ret(data_df, return_col = 'close', sig_col = None):
     fig = px.box(data_df, x=sig_col, y=return_col, points="all")
     return fig
 
+def plot_month_hit_ratio(month_dictionary, height=600 , width=1600, put_on_same_scale = True,title = 'Hit ratio',  split = True):
+    if split :
+        for month_name, data_df in month_dictionary.items():
+            fig = px.bar(data_df, x="strategy_underlying", y='value', color="type", barmode='group',
+                         title=f'hitration {month_name}')
+            fig.update_layout(barmode='group')
+            fig.show()
+    else:
+
+        dict_length = len(month_dictionary)
+        fig = make_subplots(rows=len(month_dictionary), cols=1)
+        counter = 0
+        for month_name, data_df in month_dictionary.items():
+            counter = counter + 1
+            print(f'displaying {month_name}')
+            data = []
+            for me_type in data_df['type'].unique():
+                merged_type_df = data_df[data_df['type'] == me_type].copy()
+                trace1 = go.Bar(
+                    x=merged_type_df['strategy_underlying'],
+                    y=merged_type_df['value'],
+                    name=me_type
+                )
+                fig.append_trace(trace1,  counter, 1)
+
+    #            data.append(trace1)
+
+    #        fig.append_trace(data, counter, 1)
+
+
+
+        fig.update_layout(barmode='group')
+        fig.update_layout(height=height*dict_length, width=width, title_text=title,showlegend=True)
+        fig.update_xaxes(rangeslider_visible=True)
+        return fig
+    #if put_on_same_scale:
+    #    fig.update_yaxes(range=[data_df[constituents].min().min(), data_df[constituents].max().max()])
+
+
+
 def plot_multiple_time_series(data_df, split =False, logy = True, title = 'Strategy performances', height=600 ,width=1600, put_on_same_scale = True, drop_na_inf = True):
     palette = cycle(px.colors.qualitative.Bold)
 #    palette = cycle(px.colors.qualitative.Vivid)
