@@ -670,4 +670,94 @@ def compute_average_prediction(optimal_mixing, weights_list):
         else:
             mixed_df = mixed_df + optimal_mixing[counter] * weights_
         counter = counter + 1
-    return mixed_df
\ No newline at end of file
+    return mixed_df
+
+
+def maxtimetorecovery(series):
+    series = np.asarray(series, dtype=np.float64).flatten()
+    dd_series = drawdown(series)
+
+    drawdown_stage = False
+    drawdown_regime = np.zeros(len(series))
+    drawdown_regime_stage = np.zeros(len(series))
+    counter = 0
+    drawdown_stage_counter = 0
+    for i in range(len(series)):
+        if drawdown_stage == False and abs(dd_series[i]) >1e-6 :
+            drawdown_stage = True
+            drawdown_stage_counter = drawdown_stage_counter + 1
+        if drawdown_stage == True and abs(dd_series[i]) <= 1e-6:
+            drawdown_stage = False
+        drawdown_regime[counter] = drawdown_stage
+        if drawdown_stage:
+            drawdown_regime_stage[counter] = drawdown_stage_counter
+        counter = counter + 1
+
+    unique, counts = np.unique(drawdown_regime_stage, return_counts=True)
+    #count_dict = dict(zip(unique, counts))
+    return max(counts)
+
+def get_period_kpi_per_regime_(price_df, default_metrics = [annual_return, annual_volatility, sharpe, calmar, mdd, maxtimetorecovery]):
+    if 'regime' in price_df.columns:
+        price_df = price_df.drop(columns = ['regime'])
+
+    nb_metrics = len(default_metrics)
+    results = np.zeros([nb_metrics, len(price_df.columns)])
+    # df = self.get_perf()
+    i = 0
+    for m in default_metrics:
+        j = 0
+        for a in price_df.columns:
+            try:
+                pr_df = price_df[[a]].dropna().copy()
+                results[i,j] = m(pr_df[a].values)
+
+                j += 1
+            except Exception as inst:
+                print(inst)
+                continue
+        i += 1
+        print('done')
+
+    kpis_df = pd.DataFrame(results, columns=price_df.columns, index=[m.__name__ for m in default_metrics])
+    return kpis_df
+
+
+def get_period_kpi_per_regime(price_df, default_metrics = [annual_return, annual_volatility, sharpe, calmar, mdd, maxtimetorecovery]):
+
+    if 'dates' in price_df.columns:
+        price_df = price_df.drop(columns = ['dates'])
+    if 'period' in price_df.columns:
+        price_df = price_df.drop(columns = ['period'])
+
+    kpis_per_regime_df = price_df.groupby(['regime']).apply(metrics.get_period_kpi_per_regime_)
+    return kpis_per_regime_df
+
+
+def get_period_kpi(price_df, default_metrics = [annual_return, annual_volatility, sharpe, calmar, mdd, maxtimetorecovery]):
+
+    if 'dates' in price_df.columns:
+        price_df = price_df.drop(columns = ['dates'])
+    if 'period' in price_df.columns:
+        price_df = price_df.drop(columns = ['period'])
+
+    nb_metrics = len(default_metrics)
+    results = np.zeros([nb_metrics, len(price_df.columns)])
+    # df = self.get_perf()
+    i = 0
+    for m in default_metrics:
+        j = 0
+        for a in price_df.columns:
+            try:
+                pr_df = price_df[[a]].dropna().copy()
+                results[i,j] = m(pr_df[a].values)
+
+                j += 1
+            except Exception as inst:
+                print(inst)
+                continue
+        i += 1
+        print('done')
+
+    kpis_df = pd.DataFrame(results, columns=price_df.columns, index=[m.__name__ for m in default_metrics])
+    return kpis_df
